/******************************** Larduino IO Enhance *****************************/
//                                                                                 
//  If you used this library, that means you admitd the following agreement.       
//                                                                                 
//      1.This library only can be used on Larduino core product.                  
//      2.The total current of MCU shall not exceed 150mA, if the current          
//        overload, may cause the device damage.                                   
//      3.If the device damaged by current overload, the user has to take          
//        responsibility for themselves.                                           
//                                                                                 
//  This library is used for Larduino to enhance I/O output and sink current.      
//  For safety, this library only support enhance not more than 7 continuous I/Os.
//                                                                                 
//  function explanation:                                                          
//  void LarduinoIOEnhance(enum EnhanceIORange range, enum EnhanceIOState state)   
//      The EnhanceIORange can be: D0_D7, D8_D13, A0_A5, AllPin                    
//      The EnhanceIOState can be: Enhance, Normall                                
//                                                                                 
//     -----------------------------------------------------------------
//    |      I/O     |     Mode    |   Sink Current  |  Output Current  |
//     -----------------------------------------------------------------
//    |              |    Normall  |      12.3 mA    |     36.8 mA      |
//    |     D0_D5    |--------------------------------------------------
//    |              |    Enhance  |      80.0 mA    |     63.1 mA      |
//     -----------------------------------------------------------------
//    |     D6_D7    |    Normall  |      12.3 mA    |     36.8 mA      |
//    |     D8_D13   |--------------------------------------------------
//    |     A0_A5    |    Enhance  |      28.0 mA    |     63.1 mA      |
//     -----------------------------------------------------------------
//                                                                                 
//                                                                   Author:Joinj  
//                                                            Sparking Work Space  
//                                                       E-Mail:joinj@foxmail.com  
//                                                                   May 10, 2014  


#include <LarduinoIOEnhance.h>

void setup(void)
{
    pinMode(13, OUTPUT);    //LED(D13) I/O init
    pinMode(4, OUTPUT);     //D4 I/O init
    digitalWrite(4, LOW);   //Output low, test the sink current of D4
    //digitalWrite(4, HIGH);   //Output low, test the output current of D4
}
void loop(void)
{
    delay(1000);
    // Set D0~D5 in Enhance mode, sink current can reach 80mA each I/O, 
    // output current can reach 63.1mA each I/O.
    // Set D6~D7 in Enhance mode, sink current can reach 28mA each I/O, 
    // output current can reach 63.1mA each I/O.
    LarduinoIOEnhance(D0_D7, Enhance); 
    //LED(D13) is blinking.
    digitalWrite(13,!digitalRead(13));  
    delay(1000);
    // Set D0~D7 in Normall mode, sink current is 12.3mA each I/O, 
    // output current is 36.8mA each I/O.
    LarduinoIOEnhance(D0_D7, Normall); 
}


